Learn R Programming

plumbertableau (version 0.1.1)

tableau_extension: Modify a Plumber router to function as a Tableau Analytics Extension

Description

Most of the time, you won't call this function directly. Instead, you'll place it at the end of a Plumber router, under a #* @plumber annotation, with no trailing parentheses or arguments. This tells Plumber to use the function to modify the router object.

Usage

tableau_extension

tableau_extension(pr)

Value

A modified plumber router that functions as a Tableau Analytics Extension

Arguments

pr

A plumber router

Examples

Run this code
if (FALSE) {
library(plumber)
library(plumbertableau)

#* Capitalize incoming text
#* @post /capitalize
function(req, res) {
  dat <- req$body$data
  toupper(dat)
}

#* @plumber
tableau_extension
}

Run the code above in your browser using DataLab