tableau_extension: Modify a Plumber router to function as a Tableau Analytics Extension
Description
Most of the time, you won't call this function directly. Instead, you'll
place it at the end of a Plumber router, under a #* @plumber annotation,
with no trailing parentheses or arguments. This tells Plumber to use the
function to modify the router object.
Usage
tableau_extension
tableau_extension(pr)
Value
A modified plumber router that functions as a Tableau Analytics
Extension